<?php

namespace Drupal\exportable_controllers\Entity;

use Drupal\Core\Config\Entity\ConfigEntityBase;

/**
 * Defines the Exportable controller entity.
 *
 * @ConfigEntityType(
 *   id = "exportable_controller_entity",
 *   label = @Translation("Exportable controller"),
 *   handlers = {
 *     "view_builder" = "Drupal\Core\Entity\EntityViewBuilder",
 *     "list_builder" = "Drupal\exportable_controllers\ExportableControllerEntityListBuilder",
 *     "form" = {
 *       "add" = "Drupal\exportable_controllers\Form\ExportableControllerEntityForm",
 *       "edit" = "Drupal\exportable_controllers\Form\ExportableControllerEntityForm",
 *       "delete" = "Drupal\exportable_controllers\Form\ExportableControllerEntityDeleteForm"
 *     },
 *     "route_provider" = {
 *       "html" = "Drupal\exportable_controllers\ExportableControllerEntityHtmlRouteProvider",
 *     },
 *   },
 *   config_prefix = "exportable_controller_entity",
 *   admin_permission = "administer site configuration",
 *   entity_keys = {
 *     "id" = "id",
 *     "label" = "label",
 *     "uuid" = "uuid"
 *   },
 *   links = {
 *     "add-form" = "/admin/structure/exportable_controller_entity/add",
 *     "edit-form" = "/admin/structure/exportable_controller_entity/{exportable_controller_entity}/edit",
 *     "delete-form" = "/admin/structure/exportable_controller_entity/{exportable_controller_entity}/delete",
 *     "collection" = "/admin/structure/exportable_controller_entity"
 *   },
 *   config_export = {
 *     "id" = "id",
 *     "label" = "label",
 *     "uuid" = "uuid",
 *     "status",
 *     "path",
 *     "controller",
 *     "access",
 *     "permission",
 *     "role",
 *     "custom_access",
 *   }
 * )
 */
class ExportableControllerEntity extends ConfigEntityBase implements ExportableControllerEntityInterface {

  /**
   * The Exportable controller ID.
   *
   * @var string
   */
  protected $id;

  /**
   * The Exportable controller label.
   *
   * @var string
   */
  protected $label;

  /**
   * Controller path.
   *
   * @var string
   */
  protected $path;

  /**
   * Controller handler.
   *
   * @var string
   */
  protected $controller;

  /**
   * Open access.
   *
   * @var bool
   */
  protected $access;

  /**
   * Permission ID.
   *
   * @var string
   */
  protected $permission = 'access content';

  /**
   * Role list.
   *
   * @var string
   */
  protected $role = '';

  /**
   * Custom access handler.
   *
   * @var string
   */
  protected $custom_access;

  /**
   * {@inheritdoc}
   */
  public function getPath() {
    return $this->path;
  }

  /**
   * {@inheritdoc}
   */
  public function setPath($value) {
    $this->path = $value;
    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public function getCallableController() {
    if (empty($this->controller)) {
      return '\Drupal\exportable_controllers\Controller\ExportableControllersController::build';
    }
    return $this->controller;
  }

  /**
   * {@inheritdoc}
   */
  public function setCallableController($value) {
    $this->controller = $value;
    return $this;
  }

  /**
   * {@inheritdoc}
   */
  public function canAccess() {
    return $this->access;
  }

  /**
   * {@inheritdoc}
   */
  public function setAccess(bool $access) {
    $this->access = $access;
  }

  /**
   * {@inheritdoc}
   */
  public function getPermission() {
    return $this->permission;
  }

  /**
   * {@inheritdoc}
   */
  public function setPermission(string $permission) {
    $this->permission = $permission;
  }

  /**
   * {@inheritdoc}
   */
  public function getRole() {
    return $this->role;
  }

  /**
   * {@inheritdoc}
   */
  public function setRole(string $role) {
    $this->role = $role;
  }

  /**
   * {@inheritdoc}
   */
  public function getCustomAccess() {
    return $this->custom_access;
  }

  /**
   * {@inheritdoc}
   */
  public function setCustomAccess(string $custom_access) {
    $this->custom_access = $custom_access;
  }

}
