<?php

namespace Drupal\exportable_controllers;

use Drupal\Core\Config\Entity\ConfigEntityListBuilder;
use Drupal\Core\Entity\EntityInterface;

/**
 * Provides a listing of Exportable controller entities.
 */
class ExportableControllerEntityListBuilder extends ConfigEntityListBuilder {

  /**
   * {@inheritdoc}
   */
  public function buildHeader() {
    $header['label'] = $this->t('Exportable controller');
    $header['id'] = $this->t('Machine name');
    $header['path'] = $this->t('Path');
    $header['status'] = $this->t('Active');
    return $header + parent::buildHeader();
  }

  /**
   * {@inheritdoc}
   */
  public function buildRow(EntityInterface $entity) {
    /** @var \Drupal\exportable_controllers\Entity\ExportableControllerEntityInterface $entity */
    $label = [
      '#markup' => $entity->label(),
    ];
    if ($entity->status()) {
      $path = $entity->getPath();
      if (substr($entity->getPath(), 0, 1) != '/') {
        $path = '/' . $path;
      }
      $label = [
        '#markup' => '<a href="' . $path . '">' . $entity->label() . '</a>',
      ];
    }
    $row['label'] = \Drupal::service('renderer')->render($label);
    $row['id'] = $entity->id();
    $row['Path'] = $entity->getPath();
    $row['status'] = $entity->status() ? $this->t('Enabled') : $this->t('Disabled');
    return $row + parent::buildRow($entity);
  }

}
