<?php

namespace Drupal\exportable_controllers\Routing;

use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\Routing\Route;
use Drupal\Core\Entity\EntityTypeManagerInterface;

/**
 * Defines a route subscriber to register a url configurable paths.
 */
class ExportableControllerRoutes implements ContainerInjectionInterface {

  /**
   * The entity type manager service.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * Constructs a new ExportableControllerRoutes object.
   *
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The entity type manager service.
   */
  public function __construct(
    EntityTypeManagerInterface $entity_type_manager
  ) {
    $this->entityTypeManager = $entity_type_manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('entity_type.manager')
    );
  }

  /**
   * Returns an array of route objects.
   *
   * @return \Symfony\Component\Routing\Route[]
   *   An array of route objects.
   */
  public function routes() {
    $routes = [];
    $expRoutes = $this->entityTypeManager->getStorage('exportable_controller_entity')->loadMultiple();
    /** @var \Drupal\exportable_controllers\Entity\ExportableControllerEntityInterface $route */
    foreach ($expRoutes as $route) {
      if ($route->status()) {
        $aux = [
          '_access' => $route->canAccess() ? 'TRUE' : NULL,
          '_permission' => $route->getPermission(),
          '_custom_access' => $route->getCustomAccess(),
        ];
        if (empty($aux['_access'])) {
          unset($aux['_access']);
        }
        if (!empty($route->getRole())) {
          $aux['_role'] = $route->getRole();
        }
        if (empty($aux['_custom_access'])) {
          unset($aux['_custom_access']);
        }
        if (empty($aux['_permission'])) {
          unset($aux['_permission']);
        }

        $routes[$route->id()] = new Route(
          $route->getPath(),
          [
            '_controller' => $route->getCallableController(),
            '_title' => $route->label(),
          ],
          $aux
        );
      }
    }

    return $routes;
  }

}
